==> bd_progress_bar-0.0.6.tar.gz: lib/bdprogreebar.dart <==
// Copyright (c) 2020, Salim Murshed. All rights reserved. Use of this source code
// is governed by a BSD-style license that can be found in the LICENSE file.
//
library bdprogreebar;

//
//##MIT License
//
//Copyright (c) 2020 salimmurshed12@gmail.com
//
//Name: Salim Murshed
//Country: Bangladesh
//Email: salimmurshed12@gmail.com
//
//Flutter Developer: Since 2019
//MS Expertise: Since 2012
//Freelance: Since 2013
//
//you can only use it, but it is not for re use.
//
//
//Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
//
//The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
//THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'loaders/color_loader.dart';
import 'loaders/color_loader_2.dart';
import 'loaders/color_loader_3.dart';
import 'loaders/color_loader_4.dart';
import 'loaders/color_loader_5.dart';
import 'loaders/color_loader_6.dart';
import 'loaders/color_loader_7.dart';
import 'loaders/dot_type.dart';

class Loader extends StatefulWidget {
  final Color colors;
  final Color backColors;
  Loader({
    Key key,
    this.colors,
    this.backColors,
  });

  @override
  _Loader createState() => new _Loader();
}

class _Loader extends State<Loader> {
  @override
  Widget build(BuildContext context) {
    return ColorLoader(colors: widget.colors, backColors: widget.backColors);
  }
}

class Loader2 extends StatefulWidget {
  final Color color1;
  final Color color2;
  final Color color3;
  final bool border1Revers;
  final bool border2Revers;
  final bool border3Revers;
  Loader2(
      {Key key,
      this.border1Revers = false,
      this.border2Revers = false,
      this.border3Revers = false,
      this.color1 = Colors.deepOrangeAccent,
      this.color2 = Colors.yellow,
      this.color3 = Colors.lightGreen});

  @override
  _Loader2 createState() => new _Loader2();
}

class _Loader2 extends State<Loader2> {
  @override
  Widget build(BuildContext context) {
    return ColorLoader2(
      color1: widget.color1,
      color2: widget.color2,
      color3: widget.color3,
      border1Revers: widget.border1Revers,
      border2Revers: widget.border2Revers,
      border3Revers: widget.border3Revers,
    );
  }
}

class Loader3 extends StatefulWidget {
  final double mainBall;
  final double subBall;
  final bool reverse;
  final bool onOff;
  final List<Color> color;
  Loader3(
      {Key key,
      this.reverse = false,
      this.mainBall = 20.0,
      this.subBall = 5.0,
      this.onOff = false,
      this.color = const [
        Colors.amber,
        Colors.deepOrangeAccent,
        Colors.pinkAccent,
        Colors.purple,
        Colors.yellow,
        Colors.lightGreen,
        Colors.orangeAccent,
        Colors.blueAccent
      ]});

  @override
  _Loader3 createState() => new _Loader3();
}

class _Loader3 extends State<Loader3> {
  @override
  Widget build(BuildContext context) {
    return ColorLoader3(
      reverse: widget.reverse,
      mainBall: widget.mainBall,
      subBall: widget.subBall,
      onOff: widget.onOff,
      color: widget.color,
    );
  }
}

class Loader4 extends StatefulWidget {
  final Color dotOneColor;
  final Color dotTwoColor;
  final Color dotThreeColor;
  final Duration duration;
  final DotType dotType;
  final Icon dotIcon;
  Loader4(
      {this.dotOneColor = Colors.redAccent,
      this.dotTwoColor = Colors.green,
      this.dotThreeColor = Colors.blueAccent,
      this.duration = const Duration(milliseconds: 1000),
      this.dotType = DotType.circle,
      this.dotIcon = const Icon(Icons.blur_on)});

  @override
  _Loader4 createState() => new _Loader4();
}

class _Loader4 extends State<Loader4> {
  @override
  Widget build(BuildContext context) {
    return ColorLoader4(
      dotOneColor: widget.dotOneColor,
      dotTwoColor: widget.dotTwoColor,
      dotThreeColor: widget.dotThreeColor,
      duration: widget.duration,
      dotType: widget.dotType,
      dotIcon: widget.dotIcon,
    );
  }
}

class Loader5 extends StatefulWidget {
  final Color dotOneColor;
  final Color dotTwoColor;
  final Color dotThreeColor;
  final Duration duration;
  final DotType dotType;
  final Icon dotIcon;
  Loader5(
      {this.dotOneColor = Colors.redAccent,
      this.dotTwoColor = Colors.green,
      this.dotThreeColor = Colors.blueAccent,
      this.duration = const Duration(milliseconds: 1000),
      this.dotType = DotType.circle,
      this.dotIcon = const Icon(Icons.blur_on)});

  @override
  _Loader5 createState() => new _Loader5();
}

class _Loader5 extends State<Loader5> {
  @override
  Widget build(BuildContext context) {
    return ColorLoader5(
        dotOneColor: widget.dotOneColor,
        dotTwoColor: widget.dotTwoColor,
        dotThreeColor: widget.dotThreeColor,
        duration: widget.duration,
        dotType: widget.dotType,
        dotIcon: widget.dotIcon);
  }
}

class Loader6 extends StatefulWidget {
  final bool reverse;
  Loader6({
    Key key,
    this.reverse = false,
  });

  @override
  _Loader6 createState() => new _Loader6();
}

class _Loader6 extends State<Loader6> {
  @override
  Widget build(BuildContext context) {
    return ColorLoader6(reverse: widget.reverse);
  }
}

class Loader7 extends StatefulWidget {
  final Color dotOneColor;
  final Color dotTwoColor;
  final Color dotThreeColor;
  final Duration duration;
  final Icon dotIcon1;
  final Icon dotIcon2;
  final Icon dotIcon3;
  final double iconSize;
  Loader7(
      {this.dotOneColor = Colors.redAccent,
      this.dotTwoColor = Colors.green,
      this.dotThreeColor = Colors.blueAccent,
      this.duration = const Duration(milliseconds: 1000),
      this.dotIcon1 = const Icon(Icons.blur_on),
      this.dotIcon2 = const Icon(Icons.blur_on),
      this.dotIcon3 = const Icon(Icons.blur_on),
      this.iconSize = 2.5});

  @override
  _Loader7 createState() => new _Loader7();
}

class _Loader7 extends State<Loader7> {
  @override
  Widget build(BuildContext context) {
    return ColorLoader7(
      dotOneColor: widget.dotOneColor,
      dotTwoColor: widget.dotTwoColor,
      dotThreeColor: widget.dotThreeColor,
      duration: widget.duration,
      dotIcon1: widget.dotIcon1,
      dotIcon2: widget.dotIcon2,
      dotIcon3: widget.dotIcon3,
      iconSize: widget.iconSize,
    );
  }
}

==> bd_progress_bar-0.0.9.tar.gz: lib/bdprogreebar.dart <==
// Copyright (c) 2020, Salim Murshed. All rights reserved. Use of this source code
// is governed by a BSD-style license that can be found in the LICENSE file.
//
library bd_progress_bar;

//
//##MIT License
//
//Copyright (c) 2020 salimmurshed12@gmail.com
//
//Name: Salim Murshed
//Country: Bangladesh
//Email: salimmurshed12@gmail.com
//
//Flutter Developer: Since 2019
//MS Expertise: Since 2012
//Freelance: Since 2013
//
//you can only use it, but it is not for re use.
//
//
//Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
//
//The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
//
//THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:bd_progress_bar/loaders/color_loader.dart';
import 'package:bd_progress_bar/loaders/color_loader_2.dart';
import 'package:bd_progress_bar/loaders/color_loader_3.dart';
import 'package:bd_progress_bar/loaders/color_loader_4.dart';
import 'package:bd_progress_bar/loaders/color_loader_5.dart';
import 'package:bd_progress_bar/loaders/color_loader_6.dart';
import 'package:bd_progress_bar/loaders/color_loader_7.dart';
import 'package:bd_progress_bar/loaders/dot_type.dart';

class Loader extends StatefulWidget {
  final Color colors;
  final Color backColors;
  Loader({
    Key key,
    this.colors,
    this.backColors,
  });

  @override
  _Loader createState() => new _Loader();
}

class _Loader extends State<Loader> {
  @override
  Widget build(BuildContext context) {
    return ColorLoader(colors: widget.colors, backColors: widget.backColors);
  }
}

class Loader2 extends StatefulWidget {
  final Color color1;
  final Color color2;
  final Color color3;
  final bool border1Revers;
  final bool border2Revers;
  final bool border3Revers;
  Loader2(
      {Key key,
      this.border1Revers = false,
      this.border2Revers = false,
      this.border3Revers = false,
      this.color1 = Colors.deepOrangeAccent,
      this.color2 = Colors.yellow,
      this.color3 = Colors.lightGreen});

  @override
  _Loader2 createState() => new _Loader2();
}

class _Loader2 extends State<Loader2> {
  @override
  Widget build(BuildContext context) {
    return ColorLoader2(
      color1: widget.color1,
      color2: widget.color2,
      color3: widget.color3,
      border1Revers: widget.border1Revers,
      border2Revers: widget.border2Revers,
      border3Revers: widget.border3Revers,
    );
  }
}

class Loader3 extends StatefulWidget {
  final double mainBall;
  final double subBall;
  final bool reverse;
  final bool onOff;
  final List<Color> color;
  Loader3(
      {Key key,
      this.reverse = false,
      this.mainBall = 20.0,
      this.subBall = 5.0,
      this.onOff = false,
      this.color = const [
        Colors.amber,
        Colors.deepOrangeAccent,
        Colors.pinkAccent,
        Colors.purple,
        Colors.yellow,
        Colors.lightGreen,
        Colors.orangeAccent,
        Colors.blueAccent
      ]});

  @override
  _Loader3 createState() => new _Loader3();
}

class _Loader3 extends State<Loader3> {
  @override
  Widget build(BuildContext context) {
    return ColorLoader3(
      reverse: widget.reverse,
      mainBall: widget.mainBall,
      subBall: widget.subBall,
      onOff: widget.onOff,
      color: widget.color,
    );
  }
}

class Loader4 extends StatefulWidget {
  final Color dotOneColor;
  final Color dotTwoColor;
  final Color dotThreeColor;
  final Duration duration;
  final DotType dotType;
  final Icon dotIcon;
  Loader4(
      {this.dotOneColor = Colors.redAccent,
      this.dotTwoColor = Colors.green,
      this.dotThreeColor = Colors.blueAccent,
      this.duration = const Duration(milliseconds: 1000),
      this.dotType = DotType.circle,
      this.dotIcon = const Icon(Icons.blur_on)});

  @override
  _Loader4 createState() => new _Loader4();
}

class _Loader4 extends State<Loader4> {
  @override
  Widget build(BuildContext context) {
    return ColorLoader4(
      dotOneColor: widget.dotOneColor,
      dotTwoColor: widget.dotTwoColor,
      dotThreeColor: widget.dotThreeColor,
      duration: widget.duration,
      dotType: widget.dotType,
      dotIcon: widget.dotIcon,
    );
  }
}

class Loader5 extends StatefulWidget {
  final Color dotOneColor;
  final Color dotTwoColor;
  final Color dotThreeColor;
  final Duration duration;
  final DotType dotType;
  final Icon dotIcon;
  Loader5(
      {this.dotOneColor = Colors.redAccent,
      this.dotTwoColor = Colors.green,
      this.dotThreeColor = Colors.blueAccent,
      this.duration = const Duration(milliseconds: 1000),
      this.dotType = DotType.circle,
      this.dotIcon = const Icon(Icons.blur_on)});

  @override
  _Loader5 createState() => new _Loader5();
}

class _Loader5 extends State<Loader5> {
  @override
  Widget build(BuildContext context) {
    return ColorLoader5(
        dotOneColor: widget.dotOneColor,
        dotTwoColor: widget.dotTwoColor,
        dotThreeColor: widget.dotThreeColor,
        duration: widget.duration,
        dotType: widget.dotType,
        dotIcon: widget.dotIcon);
  }
}

class Loader6 extends StatefulWidget {
  final bool reverse;
  Loader6({
    Key key,
    this.reverse = false,
  });

  @override
  _Loader6 createState() => new _Loader6();
}

class _Loader6 extends State<Loader6> {
  @override
  Widget build(BuildContext context) {
    return ColorLoader6(reverse: widget.reverse);
  }
}

class Loader7 extends StatefulWidget {
  final Color dotOneColor;
  final Color dotTwoColor;
  final Color dotThreeColor;
  final Duration duration;
  final Icon dotIcon1;
  final Icon dotIcon2;
  final Icon dotIcon3;
  final double iconSize;
  Loader7(
      {this.dotOneColor = Colors.redAccent,
      this.dotTwoColor = Colors.green,
      this.dotThreeColor = Colors.blueAccent,
      this.duration = const Duration(milliseconds: 1000),
      this.dotIcon1 = const Icon(Icons.blur_on),
      this.dotIcon2 = const Icon(Icons.blur_on),
      this.dotIcon3 = const Icon(Icons.blur_on),
      this.iconSize = 2.5});

  @override
  _Loader7 createState() => new _Loader7();
}

class _Loader7 extends State<Loader7> {
  @override
  Widget build(BuildContext context) {
    return ColorLoader7(
      dotOneColor: widget.dotOneColor,
      dotTwoColor: widget.dotTwoColor,
      dotThreeColor: widget.dotThreeColor,
      duration: widget.duration,
      dotIcon1: widget.dotIcon1,
      dotIcon2: widget.dotIcon2,
      dotIcon3: widget.dotIcon3,
      iconSize: widget.iconSize,
    );
  }
}
